@@ -75,13 +75,15 @@ def _arithmetic_worker(df, func, kw):
 
 
 class QuoteData(object):
-    _threading_local = threading.local()
+    _instance_lock = threading.Lock()
 
     def __new__(cls, *args, **kwargs):
-        """单例模式-线程隔离"""
-        if not hasattr(cls._threading_local, "_instance"):
-            cls._threading_local._instance = object.__new__(cls)
-        return cls._threading_local._instance
+        """单例模式-线程保护"""
+        if not hasattr(cls, "_instance"):
+            with cls._instance_lock:
+                if not hasattr(cls, "_instance"):
+                    cls._instance = object.__new__(cls)
+        return cls._instance
 
     def __init__(self, data_path=None):
         """本地行情数据类
