@@ -100,13 +100,15 @@ class ArithmeticQuoteValue(object):
 
 class ArithmeticContainer(object):
     """计算容器"""
-    _threading_local = threading.local()
+    _instance_lock = threading.Lock()
 
     def __new__(cls, *args, **kwargs):
-        """单例模式-线程隔离"""
-        if not hasattr(cls._threading_local, "_instance"):
-            cls._threading_local._instance = object.__new__(cls)
-        return cls._threading_local._instance
+        """单例模式-线程保护"""
+        if not hasattr(cls, "_instance"):
+            with cls._instance_lock:
+                if not hasattr(cls, "_instance"):
+                    cls._instance = object.__new__(cls)
+        return cls._instance
 
     def __init__(self):
         if not hasattr(self, '_security'):
@@ -250,6 +252,7 @@ class ArithmeticStatistics(object):
         self._update(x, n)
         if len(self._data[-n:]) > 1:
             self._result = float(np.std(self._data[-n:], ddof=1))
+        #self._result = float(np.std(self._data[-n:]))
         return self._result
 
     def sum(self, x, n=0):
