@@ -64,3 +64,22 @@ def EXPMA(N=12):
 
     """
     return EMA(**locals())
+
+
+@arithmetic_wrapper
+def BBI(N1=3, N2=6, N3=12, N4=24):
+    """多空均线
+
+    公式：
+        BBI:(MA(CLOSE,M1)+MA(CLOSE,M2)+MA(CLOSE,M3)+MA(CLOSE,M4))/4;
+    输入：
+        N1：统计的天数 N1
+        N2：统计的天数 N2
+        N3：统计的天数 N3
+        N4：统计的天数 N4
+    输出：
+        BBI的值
+
+    """
+    BBI = (MA(CLOSE,N1)+MA(CLOSE,N2)+MA(CLOSE,N3)+MA(CLOSE,N4))/4
+    return BBI
