@@ -357,23 +357,27 @@ def ROC(N=12, M=6):
 
 
 @arithmetic_wrapper
-def RSI(N=6):
+def RSI(N1=6,N2=12,N3=24):
     """相对强弱指标
 
     公式：
         LC:=REF(CLOSE,1);
         RSI:SMA(MAX(CLOSE-LC,0),N,1)/SMA(ABS(CLOSE-LC),N,1)*100;
     输入：
-        N：统计的周期数 N
+        N1：统计的周期数 N1
+        N2：统计的周期数 N2
+        N3：统计的周期数 N3
     输出：
         RSI值
     定义：
-        RETURNS=RSI{N}
+        RETURNS=(RSI{N1}, RSI{N2}, RSI{N3})
 
     """
     LC = REF(CLOSE, 1)
-    RSI = SMA(MAX(CLOSE - LC, 0), N, 1) / SMA(ABS(CLOSE - LC), N, 1) * 100
-    return RSI
+    RSI1 = SMA(MAX(CLOSE - LC, 0), N1, 1) / SMA(ABS(CLOSE - LC), N1, 1) * 100
+    RSI2 = SMA(MAX(CLOSE - LC, 0), N2, 1) / SMA(ABS(CLOSE - LC), N2, 1) * 100
+    RSI3 = SMA(MAX(CLOSE - LC, 0), N3, 1) / SMA(ABS(CLOSE - LC), N3, 1) * 100
+    return RSI1, RSI2, RSI3
 
 
 @arithmetic_wrapper
@@ -472,7 +476,7 @@ def WR(N1=10, N2=6):
         WR1: N1周期的WR值
         WR2: N2周期的WR值
     定义：
-        RETURNS=(WR{N1}, WR2{N2})
+        RETURNS=(WR{N1}, WR{N2})
     """
     WR1 = (HHV(HIGH, N1) - CLOSE) / (HHV(HIGH, N1) - LLV(LOW, N1)) * 100
     WR2 = (HHV(HIGH, N2) - CLOSE) / (HHV(HIGH, N2) - LLV(LOW, N2)) * 100
